#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

# TODO Graphingsystem:
# - Default-Template: Wenn im Graph kein "range" angegeben ist, aber
# in der Unit eine "range"-Angabe ist, dann soll diese genommen werden.
# Und dann s<C3><A4>mtliche Schablonen, die nur wegen Range
# 0..100 da sind, wieder durch generic ersetzen.

# Metric definitions for Check_MK's checks

#.
#   .--Metrics-------------------------------------------------------------.
#   |                   __  __      _        _                             |
#   |                  |  \/  | ___| |_ _ __(_) ___ ___                    |
#   |                  | |\/| |/ _ \ __| '__| |/ __/ __|                   |
#   |                  | |  | |  __/ |_| |  | | (__\__ \                   |
#   |                  |_|  |_|\___|\__|_|  |_|\___|___/                   |
#   |                                                                      |
#   +----------------------------------------------------------------------+
#   |  Definitions of metrics                                              |
#   '----------------------------------------------------------------------'

# Title are always lower case - except the first character!

metric_info["ntnx_cpu"] = {
    "title" : _("Utilization"),
    "unit"  : "%",
    "color" : "#BECF43",
}

metric_info["ntnx_mem"] = {
    "title" : _("Usage"),
    "unit"  : "%",
    "color" : "#2050A2",
}

metric_info["ntnx_iops"] = {
    "title" : _("Storage Controller IOPS"),
    "unit"  : "count",
    "color" : "#FF3333",
}

metric_info["ntnx_bandwidth"] = {
    "title" : _("Storage Controller Bandwidth"),
    "unit"  : "bytes/s",
    "color" : "#FF9900",
}

metric_info["ntnx_latency"] = {
    "title" : _("Storage Controller Latency"),
    "unit"  : "s",
    "color" : "#6666FF",
}

metric_info["ntnx_ctr_compressionratio"] = {
    "title" : _("Compression Ratio"),
    "unit"  : "count",
    "color" : "#E76F1F",
}

metric_info["ntnx_ctr_dedupratio"] = {
    "title" : _("Dedup Ratio"),
    "unit"  : "count",
    "color" : "#2050A2",
}

metric_info["ntnx_pd_exclusivesnapshot"] = {
    "title" : _("Usage"),
    "unit"  : "bytes",
    "color" : "#00ffc6",
}

metric_info["ntnx_pd_bandwidth_tx"] = {
    "title" : _("Tx"),
    "unit"  : "count",
    "color" : "#888800",
}

metric_info["ntnx_pd_bandwidth_rx"] = {
    "title" : _("Rx"),
    "unit"  : "count",
    "color" : "#880088",
}

metric_info["ntnx_fs_used"] = {
    "title" : _("Used space"),
    "unit"  : "bytes",
    "color" : "#00ffc6",
}

metric_info["ntnx_fs_size"] = {
    "title" : _("Max Capacity"),
    "unit"  : "bytes",
    "color" : "#006040",
}

metric_info["ntnx_sp_usage_ssd"] = {
    "title" : _("SSD"),
    "unit"  : "count",
    "color" : "#BECF43",
}

metric_info["ntnx_sp_usage_sata"] = {
    "title" : _("DAS-SATA"),
    "unit"  : "count",
    "color" : "#2050A2",
}

metric_info["ntnx_hosts_numVMs"] = {
    "title" : _("Total"),
    "unit"  : "count",
    "color" : "#2050A2",
}

metric_info["ntnx_hosts_cpu"] = {
    "title" : _("CPU Usage"),
    "unit"  : "%",
    "color" : "#FF6000",
}

metric_info["ntnx_vms_cpu"] = {
    "title" : _("CPU Usage"),
    "unit"  : "%",
    "color" : "#FF6000",
}

metric_info["ntnx_vms_cpu_ready"] = {
    "title" : _("CPU Ready Time"),
    "unit"  : "%",
    "color" : "#00B0C0",
}

metric_info["ntnx_hosts_mem"] = {
    "title" : _("Memory Usage"),
    "unit"  : "%",
    "color" : "#80FF40",
}

metric_info["ntnx_vms_mem"] = {
    "title" : _("Memory Usage"),
    "unit"  : "%",
    "color" : "#80FF40",
}

metric_info["ntnx_vms_pd_iops_read"] = {
    "title" : _("Read"),
    "unit"  : "count",
    "color" : "#888800",
}

metric_info["ntnx_vms_pd_iops_write"] = {
    "title" : _("Write"),
    "unit"  : "count",
    "color" : "#880088",
}

#.
#   .--Graphs--------------------------------------------------------------.
#   |                    ____                 _                            |
#   |                   / ___|_ __ __ _ _ __ | |__  ___                    |
#   |                  | |  _| '__/ _` | '_ \| '_ \/ __|                   |
#   |                  | |_| | | | (_| | |_) | | | \__ \                   |
#   |                   \____|_|  \__,_| .__/|_| |_|___/                   |
#   |                                  |_|                                 |
#   +----------------------------------------------------------------------+
#   |  Definitions of time series graphs                                   |
#   '----------------------------------------------------------------------'

# Beware: The order of the list elements of graph_info is actually important.
# It determines the order of graphs of a service, which in turn is used by
# the report definitions to determine which graph to include.

# Order of metrics in graph definitions important if you use only 'area':
# The first one must be the bigger one, then descending.
# Example: ('tablespace_size', 'area'),
#          ('tablespace_used', 'area')

graph_info.append({
    "title"     : _("Cluster CPU utilization"),
    "metrics"   : [ ("ntnx_cpu", "area"),
                ],
    "scalars" : [
                    "ntnx_cpu:warn",
                    "ntnx_cpu:crit",
    ],
    "range" : (0, 100),
})

graph_info.append({
    "title"     : _("Cluster Memory usage"),
    "metrics"   : [ ("ntnx_mem", "area"),
                ],
    "scalars" : [
                    "ntnx_mem:warn",
                    "ntnx_mem:crit",
    ],

    "range" : (0, 100),
})

graph_info.append({
    "title"     : _("Cluster-wide Controller IOPS"),
    "metrics"   : [ ("ntnx_iops", "area"),
                ],
})

graph_info.append({
    "title"     : _("Cluster-wide Controller Bandwidth"),
    "metrics"   : [ ("ntnx_bandwidth", "area"),
                ],
})

graph_info.append({
    "title"     : _("Cluster-wide Controller Latency"),
    "metrics"   : [ ("ntnx_latency", "area"),
                ],
})

graph_info.append({
    "title"     : _("Compression & Deduplication"),
    "metrics"   : [ ("ntnx_ctr_compressionratio", "line"),
                    ("ntnx_ctr_dedupratio", "line"),
                ],
})

graph_info.append({
    "title"     : _("Exclusive Snapshot"),
    "metrics"   : [ ("ntnx_pd_exclusivesnapshot", "area"),
                ],
})

graph_info.append({
    "title"     : _("Bandwidth"),
    "metrics"   : [ ("ntnx_pd_bandwidth_tx", "area"),
                    ("ntnx_pd_bandwidth_rx", "stack"),
                ],
})

graph_info.append({
    "title"     : _("Nutanix Filesystem"),
    "metrics"   : [ ("ntnx_fs_used", "area"),
                    ("ntnx_fs_size,ntnx_fs_used,-#e3fff9", "stack", _("Free space") ),
                    ("ntnx_fs_size", "line"),
                ],
    "scalars" : [
                    "ntnx_fs_used:warn",
                    "ntnx_fs_used:crit",
    ],
    "range" :       (0, "ntnx_fs_used:max"),
})

graph_info.append({
    "title"     : _("Tier-Wise Usage"),
    "metrics"   : [ ("ntnx_sp_usage_sata", "area"),
                    ("ntnx_sp_usage_ssd", "stack"),
                ],
})

graph_info.append({
    "title"     : _("NTNX Host - VM Count"),
    "metrics"   : [ ("ntnx_hosts_numVMs", "area"),
                ],
})

graph_info.append({
    "title"     : _("NTNX Host - CPU Usage"),
    "metrics"   : [ ("ntnx_hosts_cpu", "area"),
                ],
    "range"     : (0, 100),
})

graph_info.append({
    "title"     : _("NTNX VM - CPU Overview"),
    "metrics"   : [ ("ntnx_vms_cpu", "area"),
                    ("ntnx_vms_cpu_ready", "stack"),
                ],
    "range"     : (0, 100),
})

graph_info.append({
    "title"     : _("NTNX Host - Memory"),
    "metrics"   : [ ("ntnx_hosts_mem", "area"),
                ],
    "range"     : (0, 100),
})

graph_info.append({
    "title"     : _("NTNX VM - Memory"),
    "metrics"   : [ ("ntnx_vms_mem", "area"),
                ],
    "range"     : (0, 100),
})


graph_info.append({
    "title"     : _("NTNX VM - IOPS"),
    "metrics"   : [ ("ntnx_vms_pd_iops_read", "area"),
                    ("ntnx_vms_pd_iops_write", "stack"),
                ],
})
