#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-

group = "datasource_programs"

hypervisor_choices = [
    ( "AHV", _("Nutanix Acropolis"),
        Transform(
            ListChoice(
                choices = [
                    ( "alerts", _("Show Alerts") ),
                    ( "container", _("Container information") ),
                    ( "ha", _("High Availability information (for AOS 5 or higher)") ),
                    ( "hosts", _("Host information") ),
                    ( "pds", _("Protection Domain information") ),
                    ( "rs", _("Remote Tunnel information") ),
                    ( "sp", _("Storage Pool information") ),
                    ( "vms", _("Virtual Machine information") ),

                ],
                default_value = [ "alerts" ],
                allow_empty = False,
            ),
        )
    ),
    ( "ESX", _("VMware vSphere"),
        Transform(
            ListChoice(
                choices = [
                    ( "alerts", _("Show Alerts") ),
                    ( "container", _("Container information") ),
                    ( "pds", _("Protection Domain information") ),
                    ( "rs", _("Remote Tunnel information") ),
                    ( "sp", _("Storage Pool information") ),
                    ( "vms", _("Virtual Machine information") ),
                ],
                default_value = [ "alerts" ],
                allow_empty = False,
            ),
        )
    ),
]

register_rule(group,
    "special_agents:ntnx",
    Transform(
        Dictionary(
            title = _("Check Nutanix via REST-API"),
            help = _("This rule selects the Agent Nutanix instead of the normal Check_MK Agent "
                     "which collects the data through the Nutanix REST-API interface"),
            match = 'first',
            elements = [
                ( "cluster",
                  Alternative(
                      title = _("Cluster Address"),
                      help  = _("If you specify a hostname here, then a dynamic DNS lookup "
                                "will be done instead of using the IP address of the host "
                                "as configured in your host properties."),
                      elements = [
                        FixedValue(True, title = _("Use host address"), totext = ""),
                        TextAscii(title = _("Enter IP or FQDN"))
                      ],
                      default_value = True
                  )
                ),
                ( "username",
                  TextAscii(
                      title = _("Username"),
                      allow_empty = False,
                  )
                ),
                ( "password",
                  Password(
                      title = _("Password"),
                      allow_empty = False,
                  )
                ),
                ("hypervisor", CascadingDropdown(
                     title = _("Hypervisor"),
                     choices = hypervisor_choices,
                )),
            ],
            optional_keys = [""],
        ),
    default_value = {
        "hypervisor": "AHV",
    }
    )
)

